==> khloraascaf-1.7.1-py3-none-any.whl: khloraascaf/__init__.py <==
# -*- coding=utf-8 -*-

"""Init file for module path shortcuts."""

# flake8: noqa

# ============================================================================ #
#                                ASSEMBLY GRAPH                                #
# ============================================================================ #
from khloraascaf.assembly_graph import *  # DOCU be sure it's described
# ============================================================================ #
#                                  EXCEPTIONS                                  #
# ============================================================================ #
from khloraascaf.exceptions import *  # DOCU be sure to describe
# ============================================================================ #
#                                    LIBRARY                                   #
# ============================================================================ #
from khloraascaf.lib import *
# ============================================================================ #
#                                 RUN METADATA                                 #
# ============================================================================ #
from khloraascaf.run_metadata import *  # DOCU be sure to describe
# ============================================================================ #
#                              SCAFFOLDING METHODS                             #
# ============================================================================ #
from khloraascaf.scaffolding_methods import *

==> khloraascaf-1.9.0-py3-none-any.whl: khloraascaf/__init__.py <==
# -*- coding=utf-8 -*-

"""Init file for module path shortcuts."""

# flake8: noqa

# REFACTOR import precisely, not with '*'
# ============================================================================ #
#                                ASSEMBLY GRAPH                                #
# ============================================================================ #
from khloraascaf.assembly_graph import *  # DOCU be sure it's described
# ============================================================================ #
#                                  EXCEPTIONS                                  #
# ============================================================================ #
from khloraascaf.exceptions import *  # DOCU be sure to describe
# ============================================================================ #
#                                     INPUT                                    #
# ============================================================================ #
from khloraascaf.inputs import *  # DOCU be sure to describe
# ============================================================================ #
#                                    LIBRARY                                   #
# ============================================================================ #
from khloraascaf.lib import *  # DOCU be sure to describe
# ============================================================================ #
#                                 RUN METADATA                                 #
# ============================================================================ #
from khloraascaf.run_metadata import *  # DOCU be sure to describe
# ============================================================================ #
#                              SCAFFOLDING METHODS                             #
# ============================================================================ #
from khloraascaf.scaffolding_methods import *  # DOCU be sure to describe
